==> hollow-cli-1.3.9.tgz: package/esm/mwBuild.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _objectSpread from "@babel/runtime/helpers/objectSpread";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";

/**************************************************
 * Created by nanyuantingfeng on 16/08/2017 13:10.
 **************************************************/
import path from 'path';
import { fnCheckWebpackConfig, fnGetNode, fnBuildSourceMap } from './util';
import { SpeedMeasurePlugin } from './plugins';
export default function (_x, _x2) {
  return _ref.apply(this, arguments);
}

function _ref() {
  _ref = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee(context, next) {
    var cwd, devtool, rules, ENV, packageMap, outputPath, publicPath, hash, output, _context$unknownConte, unknownContextCritical, _context$speedMeasure, speedMeasure, jsChunkFileName, config, smp, webpackConfig;

    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            context.output = {};
            context.webpackConfig = {
              optimization: {}
            };
            next();
            cwd = context.cwd, devtool = context.devtool, rules = context.rules, ENV = context.ENV, packageMap = context.packageMap, outputPath = context.outputPath, publicPath = context.publicPath, hash = context.hash, output = context.output, _context$unknownConte = context.unknownContextCritical, unknownContextCritical = _context$unknownConte === void 0 ? false : _context$unknownConte, _context$speedMeasure = context.speedMeasure, speedMeasure = _context$speedMeasure === void 0 ? false : _context$speedMeasure;
            jsChunkFileName = hash ? '[name]-[hash].js' : '[name].js';
            config = _objectSpread({
              cache: true,
              entry: context.entry || packageMap.entry,
              resolve: _objectSpread({
                modules: ['node_modules', path.join(__dirname, '../node_modules')],
                extensions: ['.web.tsx', '.web.ts', '.web.jsx', '.web.js', '.ts', '.tsx', '.js', '.jsx', '.json', '.lazy.js', '.lazy.jsx', '.worker.js', '.worker.ts'],
                alias: {
                  '@babel/runtime': path.dirname(require.resolve('@babel/runtime/package.json')),
                  'react-native': 'react-native-web',
                  tslib: path.dirname(require.resolve('tslib/package.json'))
                }
              }, context.resolve),
              output: _objectSpread({
                filename: jsChunkFileName,
                chunkFilename: jsChunkFileName
              }, output),
              context: context.context || cwd,
              externals: context.externals,
              node: fnGetNode(packageMap),
              devtool: fnBuildSourceMap(devtool, ENV),
              module: {
                strictExportPresence: true,
                noParse: [/moment.js/],
                rules: rules,
                unknownContextCritical: unknownContextCritical
              },
              plugins: context.plugins
            }, context.webpackConfig);

            if (speedMeasure) {
              smp = new SpeedMeasurePlugin();
              config = smp.wrap(config);
            }

            webpackConfig = context.webpackConfig = config;

            if (outputPath) {
              webpackConfig.output.path = path.join(cwd, outputPath);
            }

            if (publicPath) {
              webpackConfig.output.publicPath = publicPath;
            }

            fnCheckWebpackConfig(webpackConfig);

          case 11:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));
  return _ref.apply(this, arguments);
}

==> hollow-cli-1.3.14.tgz: package/esm/mwBuild.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _objectSpread from "@babel/runtime/helpers/objectSpread";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";

/**************************************************
 * Created by nanyuantingfeng on 16/08/2017 13:10.
 **************************************************/
import path from 'path';
import { fnCheckWebpackConfig, fnGetNode, fnBuildSourceMap } from './util';
import { SpeedMeasurePlugin } from './plugins';
export default function (_x, _x2) {
  return _ref.apply(this, arguments);
}

function _ref() {
  _ref = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee(context, next) {
    var cwd, devtool, rules, ENV, packageMap, outputPath, publicPath, hash, output, _context$unknownConte, unknownContextCritical, _context$speedMeasure, speedMeasure, jsChunkFileName, config, smp, webpackConfig;

    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            context.output = {};
            context.webpackConfig = {
              optimization: {}
            };
            next();
            cwd = context.cwd, devtool = context.devtool, rules = context.rules, ENV = context.ENV, packageMap = context.packageMap, outputPath = context.outputPath, publicPath = context.publicPath, hash = context.hash, output = context.output, _context$unknownConte = context.unknownContextCritical, unknownContextCritical = _context$unknownConte === void 0 ? false : _context$unknownConte, _context$speedMeasure = context.speedMeasure, speedMeasure = _context$speedMeasure === void 0 ? false : _context$speedMeasure;
            jsChunkFileName = hash ? '[name]-[hash].js' : '[name].js';
            config = _objectSpread({
              cache: true,
              entry: context.entry || packageMap.entry,
              resolve: _objectSpread({
                modules: ['node_modules', path.join(__dirname, '../node_modules')],
                extensions: ['.web.tsx', '.web.ts', '.web.jsx', '.web.js', '.ts', '.tsx', '.js', '.jsx', '.json', '.lazy.js', '.lazy.jsx', '.worker.js', '.worker.ts'],
                alias: {
                  '@babel/runtime': path.dirname(require.resolve('@babel/runtime/package.json')),
                  tslib: path.dirname(require.resolve('tslib/package.json')),
                  'react-native': 'react-native-web'
                }
              }, context.resolve),
              output: _objectSpread({
                filename: jsChunkFileName,
                chunkFilename: jsChunkFileName
              }, output),
              context: context.context || cwd,
              externals: context.externals,
              node: fnGetNode(packageMap),
              devtool: fnBuildSourceMap(devtool, ENV),
              module: {
                strictExportPresence: true,
                noParse: [/moment.js/],
                rules: rules,
                unknownContextCritical: unknownContextCritical
              },
              plugins: context.plugins
            }, context.webpackConfig);

            if (speedMeasure) {
              smp = new SpeedMeasurePlugin();
              config = smp.wrap(config);
            }

            webpackConfig = context.webpackConfig = config;

            if (outputPath) {
              webpackConfig.output.path = path.join(cwd, outputPath);
            }

            if (publicPath) {
              webpackConfig.output.publicPath = publicPath;
            }

            fnCheckWebpackConfig(webpackConfig);

          case 11:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));
  return _ref.apply(this, arguments);
}
